bdkffi::bitcoin

Struct Address

pub struct Address(/* private fields */);
A bitcoin address

Implementations

Source

impl Address

pub fn new(address: String, network: Network) -> Result<Self, AddressParseError>

Parse a string as an address for the given network.

pub fn from_script( script: Arc<Script>, network: Network, ) -> Result<Self, FromScriptError>

Parse a script as an address for the given network

pub fn script_pubkey(&self) -> Arc<Script>

Return the scriptPubKey underlying an address.

pub fn to_qr_uri(&self) -> String

Return a BIP-21 URI string for this address.

pub fn is_valid_for_network(&self, network: Network) -> bool

Is the address valid for the provided network

pub fn to_address_data(&self) -> AddressData

Return the data for the address.