bdkffi::bitcoin

Struct Amount

pub struct Amount(/* private fields */);
The Amount type can be used to express Bitcoin amounts that support arithmetic and conversion to various denominations. The operations that Amount implements will panic when overflow or underflow occurs. Also note that since the internal representation of amounts is unsigned, subtracting below zero is considered an underflow and will cause a panic.

Implementations

Source

impl Amount

pub fn from_sat(satoshi: u64) -> Self

Create an Amount with satoshi precision and the given number of satoshis.

pub fn from_btc(btc: f64) -> Result<Self, ParseAmountError>

Convert from a value expressing bitcoins to an Amount.

pub fn to_sat(&self) -> u64

Get the number of satoshis in this Amount.

pub fn to_btc(&self) -> f64

Express this Amount as a floating-point value in Bitcoin. Please be aware of the risk of using floating-point numbers.