pub struct FeeRate(/* private fields */);Expand description
Represents fee rate.
This is an integer type representing fee rate in sat/kwu. It provides protection against mixing up the types as well as basic formatting features.
Implementations
Sourceimpl FeeRate
impl FeeRate
Sourcepub fn from_sat_per_vb(sat_vb: u64) -> Result<Self, FeeRateError>
pub fn from_sat_per_vb(sat_vb: u64) -> Result<Self, FeeRateError>
Constructs FeeRate from satoshis per virtual bytes.
Sourcepub fn from_sat_per_kwu(sat_kwu: u64) -> Self
pub fn from_sat_per_kwu(sat_kwu: u64) -> Self
Constructs FeeRate from satoshis per 1000 weight units.
Sourcepub fn to_sat_per_vb_ceil(&self) -> u64
pub fn to_sat_per_vb_ceil(&self) -> u64
Converts to sat/vB rounding up.
Sourcepub fn to_sat_per_vb_floor(&self) -> u64
pub fn to_sat_per_vb_floor(&self) -> u64
Converts to sat/vB rounding down.
Sourcepub fn to_sat_per_kwu(&self) -> u64
pub fn to_sat_per_kwu(&self) -> u64
Returns raw fee rate.