pub struct LeafNode(/* private fields */);Expand description
Store information about taproot leaf node.
Implementations
Sourceimpl LeafNode
impl LeafNode
Sourcepub fn leaf_hash(&self) -> Option<String>
pub fn leaf_hash(&self) -> Option<String>
Computes a leaf hash for this ScriptLeaf if the leaf is known. This TapLeafHash is useful while signing taproot script spends. See LeafNode::node_hash for computing the TapNodeHash which returns the hidden node hash if the node is hidden.
Sourcepub fn node_hash(&self) -> String
pub fn node_hash(&self) -> String
Computes the [TapNodeHash] for this [ScriptLeaf]. This returns the
leaf hash if the leaf is known and the hidden node hash if the leaf is
hidden.
See also, [bdk_electrum::bdk_core::bitcoin::taproot::LeafNode::leaf_hash].
Sourcepub fn script(&self) -> Option<Arc<Script>>
pub fn script(&self) -> Option<Arc<Script>>
Returns reference to the leaf script if the leaf is known.
Sourcepub fn leaf_version(&self) -> Option<u8>
pub fn leaf_version(&self) -> Option<u8>
Returns leaf version of the script if the leaf is known.
Sourcepub fn merkle_branch(&self) -> Vec<String>
pub fn merkle_branch(&self) -> Vec<String>
Returns reference to the merkle proof (hashing partners) to get this
node in form of [TaprootMerkleBranch].