bdkffi::bitcoin

Struct NodeInfo

pub struct NodeInfo(/* private fields */);
Represents the node information in taproot tree. In contrast to TapTree, this is allowed to have hidden leaves as children.

Helper type used in merkle tree construction allowing one to build sparse merkle trees. The node represents part of the tree that has information about all of its descendants. See how TaprootBuilder works for more details. You can use TaprootSpendInfo::from_node_info to a get a TaprootSpendInfo from the merkle root NodeInfo.

Implementations

Source

impl NodeInfo

pub fn leaf_nodes(&self) -> Vec<Arc<LeafNode>>

Creates an iterator over all leaves (including hidden leaves) in the tree.

pub fn node_hash(&self) -> String

Returns the root TapNodeHash of this node info.