pub struct Output {
pub redeem_script: Option<Arc<Script>>,
pub witness_script: Option<Arc<Script>>,
pub bip32_derivation: HashMap<String, KeySource>,
pub tap_internal_key: Option<String>,
pub tap_tree: Option<Arc<TapTree>>,
pub tap_key_origins: HashMap<String, TapKeyOrigin>,
pub proprietary: HashMap<ProprietaryKey, Vec<u8>>,
pub unknown: HashMap<Key, Vec<u8>>,
}Expand description
A key-value map for an output of the corresponding index in the unsigned transaction.
Fields
redeem_script: Option<Arc<Script>>The redeem script for this output.
witness_script: Option<Arc<Script>>The witness script for this output.
bip32_derivation: HashMap<String, KeySource>Map of public keys needed to spend this output to their corresponding master key fingerprints and derivation paths.
tap_internal_key: Option<String>Taproot Internal key.
tap_tree: Option<Arc<TapTree>>Taproot Output tree (structured record).
tap_key_origins: HashMap<String, TapKeyOrigin>Map of tap root x only keys to origin info and leaf hashes contained in it.
proprietary: HashMap<ProprietaryKey, Vec<u8>>Proprietary key-value pairs for this output.
unknown: HashMap<Key, Vec<u8>>Unknown key-value pairs for this output.