pub struct TapScriptSigKey {
pub xonly_pubkey: String,
pub tap_leaf_hash: String,
}Fields
xonly_pubkey: StringAn x-only public key, used for verification of Taproot signatures and serialized according to BIP-340.
tap_leaf_hash: StringTaproot-tagged hash with tag “TapLeaf”. This is used for computing tapscript script spend hash.