bdkffi::bitcoin

Struct TapTree

pub struct TapTree(/* private fields */);
Taproot Tree representing a complete binary tree without any hidden nodes.

This is in contrast to NodeInfo, which allows hidden nodes. The implementations for Eq, PartialEq and Hash compare the merkle root of the tree

Implementations

Source

impl TapTree

pub fn root_hash(&self) -> String

Returns the root TapNodeHash of this tree.

pub fn node_info(&self) -> Arc<NodeInfo>

Gets the reference to inner NodeInfo of this tree root.