pub struct Address(/* private fields */);Expand description
A bitcoin address
Implementations
Sourceimpl Address
impl Address
Sourcepub fn new(address: String, network: Network) -> Result<Self, AddressParseError>
pub fn new(address: String, network: Network) -> Result<Self, AddressParseError>
Parse a string as an address for the given network.
Sourcepub fn from_script(
script: Arc<Script>,
network: Network,
) -> Result<Self, FromScriptError>
pub fn from_script( script: Arc<Script>, network: Network, ) -> Result<Self, FromScriptError>
Parse a script as an address for the given network
Sourcepub fn script_pubkey(&self) -> Arc<Script>
pub fn script_pubkey(&self) -> Arc<Script>
Return the scriptPubKey underlying an address.
Sourcepub fn is_valid_for_network(&self, network: Network) -> bool
pub fn is_valid_for_network(&self, network: Network) -> bool
Is the address valid for the provided network
Sourcepub fn to_address_data(&self) -> AddressData
pub fn to_address_data(&self) -> AddressData
Return the data for the address.