pub struct Header {
pub version: i32,
pub prev_blockhash: Arc<BlockHash>,
pub merkle_root: Arc<TxMerkleNode>,
pub time: u32,
pub bits: u32,
pub nonce: u32,
}Expand description
Bitcoin block header. Contains all the block’s information except the actual transactions, but including a root of a merkle tree committing to all transactions in the block.
Fields
version: i32Block version, now repurposed for soft fork signalling.
prev_blockhash: Arc<BlockHash>Reference to the previous block in the chain.
merkle_root: Arc<TxMerkleNode>The root hash of the merkle tree of transactions in the block.
time: u32The timestamp of the block, as claimed by the miner.
bits: u32The target value below which the blockhash must lie.
nonce: u32The nonce, selected to obtain a low enough blockhash.