pub struct TapTree(/* private fields */);Expand description
Taproot Tree representing a complete binary tree without any hidden nodes.
This is in contrast to NodeInfo, which allows hidden nodes. The implementations for Eq, PartialEq and Hash compare the merkle root of the tree
Implementations