pub struct TxOut {
pub value: Arc<Amount>,
pub script_pubkey: Arc<Script>,
}Expand description
Bitcoin transaction output.
Defines new coins to be created as a result of the transaction, along with spending conditions (“script”, aka “output script”), which an input spending it must satisfy.
An output that is not yet spent by an input is called Unspent Transaction Output (“UTXO”).
Fields
value: Arc<Amount>The value of the output, in satoshis.
script_pubkey: Arc<Script>The script which must be satisfied for the output to be spent.