pub type Network = Network;Aliased Type
enum Network {
Bitcoin,
Testnet,
Testnet4,
Signet,
Regtest,
}Variants
Bitcoin
Mainnet Bitcoin.
Testnet
Bitcoin’s testnet network. (In future versions this will be combined into a single variant containing the version)
Testnet4
Bitcoin’s testnet4 network. (In future versions this will be combined into a single variant containing the version)
Signet
Bitcoin’s signet network.
Regtest
Bitcoin’s regtest network.